@@ -27,12 +27,12 @@ __all__ = ("DeploymentSuccessfulWaiter",)
 
 class DeploymentSuccessfulWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters.html#deploymentsuccessfulwaiter)
     """
 
-    def wait(self, *, deploymentId: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, deploymentId: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters.html#deploymentsuccessfulwaiter)
         """
